@@ -1,8 +1,9 @@
-package App::pherkin;
-$App::pherkin::VERSION = '0.82';
-use strict;
+use v5.14;
 use warnings;
 
+package App::pherkin 0.85;
+
+
 use lib;
 use Getopt::Long;
 use Module::Runtime qw(use_module module_notional_filename);
@@ -14,6 +15,8 @@ use Data::Dumper;
 use File::Spec;
 use Path::Class qw/file dir/;
 
+use Cucumber::TagExpressions;
+
 use Test::BDD::Cucumber::I18n
     qw(languages langdef readable_keywords keyword_to_subname);
 use Test::BDD::Cucumber::Loader;
@@ -22,8 +25,7 @@ use Moo;
 use Types::Standard qw( ArrayRef Bool Str );
 has 'step_paths' => ( is => 'rw', isa => ArrayRef, default => sub { [] } );
 has 'extensions' => ( is => 'rw', isa => ArrayRef, default => sub { [] } );
-has 'tags'       => ( is => 'rw', isa => ArrayRef, required => 0 );
-has 'tag_scheme' => ( is => 'rw', isa => ArrayRef, required => 0 );
+has 'tags'       => ( is => 'rw', isa => Str,      required => 0 );
 has 'match_only' => ( is => 'rw', isa => Bool,     default => 0 );
 has 'matching'   => ( is => 'rw', isa => Str,      default => 'first');
 has 'strict'     => ( is => 'rw', isa => Bool,     default => 0 );
@@ -36,7 +38,7 @@ App::pherkin - Run Cucumber tests from the command line
 
 =head1 VERSION
 
-version 0.82
+version 0.85
 
 =head1 SYNOPSIS
 
@@ -118,9 +120,8 @@ sub _run_tests {
     $harness->startup();
 
     my $tag_spec;
-    if ( $self->tag_scheme ) {
-        $tag_spec = Test::BDD::Cucumber::Model::TagSpec->new(
-            { tags => $self->tag_scheme } );
+    if ( $self->tags ) {
+        $tag_spec = Cucumber::TagExpressions->parse( $self->tags );
     }
 
     $executor->execute( $_, $harness, $tag_spec ) for @features;
@@ -145,6 +146,9 @@ sub _run_tests {
 sub _initialize_harness {
     my ( $self, $harness_module ) = @_;
 
+    my $harness_args_string = undef;
+    ( $harness_module, $harness_args_string ) = split /\(/, $harness_module, 2; 
+    
     unless ( $harness_module =~ m/::/ ) {
         $harness_module = "Test::BDD::Cucumber::Harness::" . $harness_module;
     }
@@ -152,7 +156,15 @@ sub _initialize_harness {
     eval { use_module($harness_module) }
         || die "Unable to load harness [$harness_module]: $@";
 
-    $self->harness( $harness_module->new() );
+    if ( $harness_args_string ) {
+        my %harness_args;
+        eval "%harness_args = ($harness_args_string; 1"
+           or die $@;
+        $self->harness( $harness_module->new( %harness_args ) );
+    } else {
+        $self->harness( $harness_module->new() );
+    }
+    
 }
 
 sub _find_config_file {
@@ -317,7 +329,7 @@ sub _process_arguments {
         output     => [ 'o|output=s' ],
         strict     => [ 'strict' ],
         steps      => [ 's|steps=s@', [] ],
-        tags       => [ 't|tags=s@', [] ],
+        tags       => [ 't|tags=s' ],
         i18n       => [ 'i18n=s' ],
         extensions => [ 'e|extension=s@', [] ],
         matching   => [ 'matching=s' ],
@@ -470,9 +482,6 @@ sub _process_arguments {
     # Store any extra step paths
     $self->step_paths( $deref->('steps') );
 
-    # Store our TagSpecScheme
-    $self->tag_scheme( $self->_process_tags( @{ $deref->('tags') } ) );
-
     $self->matching( $deref->('matching') )
         if $deref->('matching');
 
@@ -485,42 +494,6 @@ sub _process_arguments {
     return ( pop @ARGV );
 }
 
-sub _process_tags {
-    my ( $self, @tags ) = @_;
-
-    # This is a bit faffy and possibly suboptimal.
-    my $tag_scheme = [];
-    my @ands       = ();
-
-    # Iterate over our commandline tag strings.
-    foreach my $tag (@tags) {
-        my @parts = ();
-
-        foreach my $part ( split( ',', $tag ) ) {
-
-            # Trim any @ or ~@ from the front of the tag
-            $part =~ s/^(~?)@//;
-
-            # ~@tag => "NOT tag" => [ not => tag ]
-            if ( defined $1 and $1 eq '~' ) {
-                push @parts, [ not => $part ];
-            } else {
-                push @parts, $part;
-            }
-        }
-
-        # @tag,@cow => "@tag OR @cow" => [ or => tag, cow ]
-        # (It's simpler to always stick an 'or' on the front.)
-        push @ands, [ or => @parts ];
-    }
-
-    # -t @tag -t @cow => "@tag AND @cow" => [ and => tag, cow ]
-    # (It's simpler to always stick an 'and' on the front.)
-    $tag_scheme = [ and => @ands ];
-
-    return $tag_scheme;
-}
-
 sub _print_languages {
 
     my @languages = languages();
@@ -613,7 +586,7 @@ Peter Sergeant C<pete@clueball.com>
 
 =head1 LICENSE
 
-  Copyright 2019-2021, Erik Huelsmann
+  Copyright 2019-2023, Erik Huelsmann
   Copyright 2011-2019, Peter Sergeant; Licensed under the same terms as Perl
 
 =cut
