@@ -1,17 +1,18 @@
-package TAP::Parser::SourceHandler::Feature;
-$TAP::Parser::SourceHandler::Feature::VERSION = '0.84';
+use v5.14;
+use warnings;
+
+package TAP::Parser::SourceHandler::Feature 0.85;
+
 =head1 NAME
 
 TAP::Parser::SourceHandler::Feature - Test::BDD::Cucumber's prove integration
 
 =head1 VERSION
 
-version 0.84
+version 0.85
 
 =cut
 
-use strict;
-use warnings;
 
 use Path::Class qw/file/;
 use Test2::API qw/context/;
