@@ -1,7 +1,5 @@
-package Test::BDD::Cucumber;
-$Test::BDD::Cucumber::VERSION = '0.81';
-use strict;
-use warnings;
+package Test::BDD::Cucumber 0.85;
+
 1;
 
 # CODE ENDS
@@ -12,7 +10,7 @@ Test::BDD::Cucumber - Feature-complete Cucumber-style testing in Perl
 
 =head1 VERSION
 
-version 0.81
+version 0.85
 
 =head1 SYNOPSIS
 
@@ -138,7 +136,7 @@ Ben Rodgers C<ben@bdr.org>
 
 =head1 LICENSE
 
-  Copyright 2019-2021, Erik Huelsmann
+  Copyright 2019-2023, Erik Huelsmann
   Copyright 2011-2019, Peter Sergeant; Licensed under the same terms as Perl
 
 =cut
