@@ -1,8 +1,9 @@
-package Test::BDD::Cucumber::Errors;
-$Test::BDD::Cucumber::Errors::VERSION = '0.84';
-use strict;
+use v5.14;
 use warnings;
 
+package Test::BDD::Cucumber::Errors 0.85;
+
+
 require Exporter;
 our @ISA       = qw(Exporter);
 our @EXPORT_OK = qw(parse_error_from_line);
@@ -13,7 +14,7 @@ Test::BDD::Cucumber::Errors - Consistently formatted errors
 
 =head1 VERSION
 
-version 0.84
+version 0.85
 
 =head1 DESCRIPTION
 
