@@ -1,12 +1,15 @@
-package Test::BDD::Cucumber::Harness;
-$Test::BDD::Cucumber::Harness::VERSION = '0.84';
+use v5.14;
+use warnings;
+
+package Test::BDD::Cucumber::Harness 0.85;
+
 =head1 NAME
 
 Test::BDD::Cucumber::Harness - Base class for creating harnesses
 
 =head1 VERSION
 
-version 0.84
+version 0.85
 
 =head1 DESCRIPTION
 
@@ -22,8 +25,6 @@ interacting with L<Test::BDD::Cucumber::Harness::Data>.
 
 =cut
 
-use strict;
-use warnings;
 use Moo;
 use Types::Standard qw( ArrayRef );
 
