@@ -1,12 +1,15 @@
-package Test::BDD::Cucumber::Harness::Data;
-$Test::BDD::Cucumber::Harness::Data::VERSION = '0.81';
+use v5.14;
+use warnings;
+
+package Test::BDD::Cucumber::Harness::Data 0.85;
+
 =head1 NAME
 
 Test::BDD::Cucumber::Harness::Data - Builds up an internal data representation of test passes / failures
 
 =head1 VERSION
 
-version 0.81
+version 0.85
 
 =head1 DESCRIPTION
 
@@ -14,8 +17,6 @@ A L<Test::BDD::Cucumber::Harness> subclass which collates test data
 
 =cut
 
-use strict;
-use warnings;
 use Moo;
 use Types::Standard qw( HashRef ArrayRef );
 use Test::More;
@@ -190,7 +191,7 @@ Peter Sergeant C<pete@clueball.com>
 
 =head1 LICENSE
 
-  Copyright 2019-2021, Erik Huelsmann
+  Copyright 2019-2023, Erik Huelsmann
   Copyright 2011-2019, Peter Sergeant; Licensed under the same terms as Perl
 
 =cut
