@@ -1,12 +1,15 @@
-package Test::BDD::Cucumber::Harness::TAP;
-$Test::BDD::Cucumber::Harness::TAP::VERSION = '0.84';
+use v5.14;
+use warnings;
+
+package Test::BDD::Cucumber::Harness::TAP 0.85;
+
 =head1 NAME
 
 Test::BDD::Cucumber::Harness::TAP - Generate results in TAP format
 
 =head1 VERSION
 
-version 0.84
+version 0.85
 
 =head1 DESCRIPTION
 
@@ -22,8 +25,6 @@ Boolean - makes tests with no matcher fail
 
 =cut
 
-use strict;
-use warnings;
 use Moo;
 
 use Types::Standard qw( Bool InstanceOf );
