@@ -1,12 +1,15 @@
-package Test::BDD::Cucumber::Harness::TermColor;
-$Test::BDD::Cucumber::Harness::TermColor::VERSION = '0.82';
+use v5.14;
+use warnings;
+
+package Test::BDD::Cucumber::Harness::TermColor 0.85;
+
 =head1 NAME
 
 Test::BDD::Cucumber::Harness::TermColor - Prints colorized text to the screen
 
 =head1 VERSION
 
-version 0.82
+version 0.85
 
 =head1 DESCRIPTION
 
@@ -22,8 +25,6 @@ in the output.
 
 =cut
 
-use strict;
-use warnings;
 use Moo;
 use Types::Standard qw( Str HashRef FileHandle );
 
@@ -314,7 +315,7 @@ Peter Sergeant C<pete@clueball.com>
 
 =head1 LICENSE
 
-  Copyright 2019-2021, Erik Huelsmann
+  Copyright 2019-2023, Erik Huelsmann
   Copyright 2011-2019, Peter Sergeant; Licensed under the same terms as Perl
 
 =cut
