@@ -1,5 +1,8 @@
-package Test::BDD::Cucumber::I18n;
-$Test::BDD::Cucumber::I18n::VERSION = '0.84';
+use v5.14;
+use warnings;
+
+package Test::BDD::Cucumber::I18n 0.85;
+
 =encoding utf8
 
 =head1 NAME
@@ -8,7 +11,7 @@ Test::BDD::Cucumber::I18N - Internationalization
 
 =head1 VERSION
 
-version 0.84
+version 0.85
 
 =head1 DESCRIPTION
 
@@ -33,8 +36,6 @@ Internationalization of feature files and step definitions.
 
 =cut
 
-use strict;
-use warnings;
 use utf8;
 
 use base 'Exporter';
