@@ -1,12 +1,15 @@
-package Test::BDD::Cucumber::Loader;
-$Test::BDD::Cucumber::Loader::VERSION = '0.84';
+use v5.14;
+use warnings;
+
+package Test::BDD::Cucumber::Loader 0.85;
+
 =head1 NAME
 
 Test::BDD::Cucumber::Loader - Simplify loading of Step Definition and feature files
 
 =head1 VERSION
 
-version 0.84
+version 0.85
 
 =head1 DESCRIPTION
 
@@ -28,8 +31,6 @@ the feature directory for C<*_steps.pl> files.
 
 =cut
 
-use strict;
-use warnings;
 
 use Path::Class;
 use File::Find::Rule;
