@@ -1,5 +1,8 @@
-package Test::BDD::Cucumber::Model::Document;
-$Test::BDD::Cucumber::Model::Document::VERSION = '0.81';
+use v5.14;
+use warnings;
+
+package Test::BDD::Cucumber::Model::Document 0.85;
+
 use Moo;
 use Types::Standard qw( Str ArrayRef InstanceOf );
 use Test::BDD::Cucumber::Model::Line;
@@ -10,7 +13,7 @@ Test::BDD::Cucumber::Model::Document - Model to represent a feature file on disk
 
 =head1 VERSION
 
-version 0.81
+version 0.85
 
 =head1 DESCRIPTION
 
@@ -80,7 +83,7 @@ Peter Sergeant C<pete@clueball.com>
 
 =head1 LICENSE
 
-  Copyright 2019-2021, Erik Huelsmann
+  Copyright 2019-2023, Erik Huelsmann
   Copyright 2011-2019, Peter Sergeant; Licensed under the same terms as Perl
 
 =cut
