@@ -1,12 +1,15 @@
-package Test::BDD::Cucumber::Model::Result;
-$Test::BDD::Cucumber::Model::Result::VERSION = '0.84';
+use v5.14;
+use warnings;
+
+package Test::BDD::Cucumber::Model::Result 0.85;
+
 =head1 NAME
 
 Test::BDD::Cucumber::Model::Result - Encapsulates a result state
 
 =head1 VERSION
 
-version 0.84
+version 0.85
 
 =head1 DESCRIPTION
 
@@ -14,8 +17,6 @@ Encapsulation of result state - whether that's for a step, scenario, or feature
 
 =cut
 
-use strict;
-use warnings;
 use Moo;
 use Types::Standard qw( Enum Str );
 
