@@ -1,12 +1,21 @@
-package Test::BDD::Cucumber::Model::TagSpec;
-$Test::BDD::Cucumber::Model::TagSpec::VERSION = '0.84';
+use v5.14;
+use warnings;
+
+package Test::BDD::Cucumber::Model::TagSpec 0.85;
+
 =head1 NAME
 
 Test::BDD::Cucumber::Model::TagSpec - Encapsulates tag selectors
 
 =head1 VERSION
 
-version 0.84
+version 0.85
+
+=head1 STATUS
+
+DEPRECATED - This module's functionality has been superseeded by
+L<Cucumber::TagExpressions>. A module published by the Cucumber
+project, with cross-implementation tests to achieve overall consistency.
 
 =head1 DESCRIPTION
 
@@ -15,8 +24,6 @@ way.
 
 =cut
 
-use strict;
-use warnings;
 use Moo;
 use List::Util qw( all any );
 use Types::Standard qw( ArrayRef );
