@@ -1,12 +1,15 @@
-package Test::BDD::Cucumber::Parser;
-$Test::BDD::Cucumber::Parser::VERSION = '0.81';
+use v5.14;
+use warnings;
+
+package Test::BDD::Cucumber::Parser 0.85;
+
 =head1 NAME
 
 Test::BDD::Cucumber::Parser - Parse Feature files
 
 =head1 VERSION
 
-version 0.81
+version 0.85
 
 =head1 DESCRIPTION
 
@@ -29,8 +32,6 @@ L<Test::BDD::Cucumber::Model::Feature> object on success.
 
 =cut
 
-use strict;
-use warnings;
 
 use Test::BDD::Cucumber::Model::Dataset;
 use Test::BDD::Cucumber::Model::Document;
@@ -524,7 +525,7 @@ Peter Sergeant C<pete@clueball.com>
 
 =head1 LICENSE
 
-  Copyright 2019-2021, Erik Huelsmann
+  Copyright 2019-2023, Erik Huelsmann
   Copyright 2011-2019, Peter Sergeant; Licensed under the same terms as Perl
 
 =cut
