@@ -1,5 +1,8 @@
-package Test::BDD::Cucumber::StepContext;
-$Test::BDD::Cucumber::StepContext::VERSION = '0.84';
+use v5.14;
+use warnings;
+
+package Test::BDD::Cucumber::StepContext 0.85;
+
 use Moo;
 use Types::Standard qw( Bool Str HashRef ArrayRef InstanceOf );
 use List::Util qw( first );
@@ -10,7 +13,7 @@ Test::BDD::Cucumber::StepContext - Data made available to step definitions
 
 =head1 VERSION
 
-version 0.84
+version 0.85
 
 =head1 DESCRIPTION
 
