@@ -1,17 +1,18 @@
-package Test::BDD::Cucumber::StepFile;
-$Test::BDD::Cucumber::StepFile::VERSION = '0.84';
+use v5.14;
+use warnings;
+
+package Test::BDD::Cucumber::StepFile 0.85;
+
 =head1 NAME
 
 Test::BDD::Cucumber::StepFile - Functions for creating and loading Step Definitions
 
 =head1 VERSION
 
-version 0.84
+version 0.85
 
 =cut
 
-use strict;
-use warnings;
 use utf8;
 
 use Carp qw/croak/;
