@@ -1,15 +1,16 @@
-package Test::BDD::Cucumber::Util;
-$Test::BDD::Cucumber::Util::VERSION = '0.81';
-use strict;
+use v5.14;
 use warnings;
 
+package Test::BDD::Cucumber::Util 0.85;
+
+
 =head1 NAME
 
 Test::BDD::Cucumber::Util - Some functions used throughout the code
 
 =head1 VERSION
 
-version 0.81
+version 0.85
 
 =head1 DESCRIPTION
 
@@ -53,7 +54,7 @@ Peter Sergeant C<pete@clueball.com>
 
 =head1 LICENSE
 
-  Copyright 2019-2021, Erik Huelsmann
+  Copyright 2019-2023, Erik Huelsmann
   Copyright 2011-2019, Peter Sergeant; Licensed under the same terms as Perl
 
 =cut
